OiRA

Help

1. Suunnittelu
2. Osallistuminen ja yhteistyö
3. Tunnistaminen + Arviointi
4. Toimintasuunnitelma
5. Raportti
6. Riskinarvioinnin tila 0%

# Raportointi

Olet nyt saanut valmiiksi riskien arvioinnin ja laatinut toimintasuunnitelman riskien hallintaan. Sovellus kerää kaikki nämä kirjaamasi tiedot raportiksi, jonka voit ladata omalle tietokoneellesi ja tarvittaessa muokata siellä. Voit halutessasi kirjoittaa alla olevaan kenttään raporttiin lisättäviä kommentteja ja lisätietoja.

Tallenna ja jatka

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More